.. _user_documentation:

Documentation
=============

.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   tutorials
   user_guide
   estimator_overview
   glossary
   changelog
   related_software

.. grid:: 1 2 2 2
    :gutter: 3

    .. grid-item-card::
        :text-align: center

        Installation

        ^^^

        Stable version, developer version, and build requirements.

        +++

        .. button-ref:: installation
            :color: primary
            :click-parent:
            :expand:

            Installation Guide

    .. grid-item-card::
        :text-align: center

        Tutorials

        ^^^

        `aeon` tutorials.

        +++

        .. button-ref:: tutorials
            :color: primary
            :click-parent:
            :expand:

            Tutorials

    .. grid-item-card::
        :text-align: center

        User Guide

        ^^^

        `aeon` user guide.

        +++

        .. button-ref:: user_guide
            :color: primary
            :click-parent:
            :expand:

            User Guide

    .. grid-item-card::
        :text-align: center

        Estimator Overview

        ^^^

        Overview of all estimators in `aeon`.

        +++

        .. button-ref:: estimator_overview
            :color: primary
            :click-parent:
            :expand:

            Estimator Overview

    .. grid-item-card::
        :text-align: center

        Glossary

        ^^^

        Glossary of common terms and API elements in `aeon`.

        +++

        .. button-ref:: glossary
            :color: primary
            :click-parent:
            :expand:

            Glossary

    .. grid-item-card::
        :text-align: center

        Change Logs

        ^^^

        Version change logs.

        +++

        .. button-ref:: changelog
            :color: primary
            :click-parent:
            :expand:

            Change Logs

    .. grid-item-card::
        :text-align: center

        Related Software

        ^^^

        Software related to `aeon` and time series.

        +++

        .. button-ref:: related_software
            :color: primary
            :click-parent:
            :expand:

            Related Software
